@@ -216,6 +216,7 @@ format_text (GtkSheet *sheet, int *justification, gchar *text, char *label)
   }
   else
     {
+    intspace=MIN(intspace, strlen(text)-digspace-1);
     sprintf (label, "%*.*f", intspace, DEFAULT_PRESICION, val);
     if(strlen(label) > space)
       sprintf (label, "%*.*E", intspace, DEFAULT_PRESICION, val);
@@ -295,20 +296,17 @@ build_example1(GtkWidget *widget)
 {
  GtkSheet *sheet;
  GtkSheetRange range;
+ GdkColor color;
+ GdkFont *font;
+ gchar font_name1[]="-bitstream-charter-bold-r-normal--36-360-72-72-p-0-iso8859-1";
+ gchar font_name2[]="-bitstream-charter-bold-r-normal--28-280-72-72-p-0-iso8859-1";
+ gchar font_name3[]="-bitstream-charter-bold-r-normal--20-200-72-72-p-0-iso8859-1";
+ gchar font_name4[]="-itc-avantgarde-demi-r-normal-*-*-140-*-*-p-*-iso8859-1";
+
  gchar name[10];
  gint i;
 
  sheet=GTK_SHEET(widget);
- gtk_sheet_set_cell(sheet, 0,0, GTK_JUSTIFY_LEFT,
-                    "You can drag & drop the selection");
- gtk_sheet_set_cell(sheet, 1,0, GTK_JUSTIFY_LEFT,
-                    "and resize it clicking the right-bottom corner");
- gtk_sheet_set_cell(sheet, 3,0, GTK_JUSTIFY_LEFT,
-                    "Store the selection on the clipboard pressing Ctrl-C");
- gtk_sheet_set_cell(sheet, 4,0, GTK_JUSTIFY_LEFT,
-                    "(The selection handler has not been implemented yet)");
-
-
 
  for(i=0; i<=sheet->maxcol; i++){
    name[0]='A'+i;
@@ -317,13 +315,75 @@ build_example1(GtkWidget *widget)
    gtk_sheet_set_column_title(sheet, i, name);
  }
 
- range.row0=2;
- range.rowi=6;
+ range.row0=1;
+ range.rowi=2;
  range.col0=1;
- range.coli=2;
+ range.coli=3;
 
  gtk_sheet_clip_range(sheet, range);
 
+ font=gdk_font_load(font_name2);
+ gtk_sheet_range_set_font(sheet, range, font);
+
+ gdk_color_parse("red", &color);
+ gdk_color_alloc(gtk_widget_get_colormap(widget), &color);
+ gtk_sheet_range_set_foreground(sheet, range, &color);
+
+ gtk_sheet_set_cell(sheet, 1,2, GTK_JUSTIFY_CENTER,
+                    "Welcome to");
+
+ range.row0=2;
+
+ font=gdk_font_load(font_name1);
+ gtk_sheet_range_set_font(sheet, range, font);
+
+ gdk_color_parse("blue", &color);
+ gdk_color_alloc(gtk_widget_get_colormap(widget), &color);
+ gtk_sheet_range_set_foreground(sheet, range, &color);
+
+ gtk_sheet_set_cell(sheet, 2,2, GTK_JUSTIFY_CENTER,
+                    "GtkSheet");
+
+ range.row0=3;
+ range.rowi=3;
+ range.col0=0;
+ range.coli=4;
+ gdk_color_parse("dark gray", &color);
+ gdk_color_alloc(gtk_widget_get_colormap(widget), &color);
+ gtk_sheet_range_set_background(sheet, range, &color);
+ gdk_color_parse("green", &color);
+ gdk_color_alloc(gtk_widget_get_colormap(widget), &color);
+ gtk_sheet_range_set_foreground(sheet, range, &color);
+ font=gdk_font_load(font_name3);
+ gtk_sheet_range_set_font(sheet, range, font);
+ gtk_sheet_set_cell(sheet,3,2,GTK_JUSTIFY_CENTER,
+      "a Matrix widget for Gtk+");
+
+ range.row0=4;
+ range.rowi=11;
+ range.col0=0;
+ range.coli=10;
+ font=gdk_font_load(font_name4);
+ gtk_sheet_range_set_font(sheet, range, font);
+ gtk_sheet_set_cell(sheet,4,0,GTK_JUSTIFY_LEFT,
+"GtkSheet is a matrix where you can allocate cells of text.");
+ gtk_sheet_set_cell(sheet,5,0,GTK_JUSTIFY_LEFT,
+"Cell contents can be edited interactively with an specially designed entry");
+ gtk_sheet_set_cell(sheet,6,0,GTK_JUSTIFY_LEFT,
+"You can change width, height, background color, foreground color, border");
+ gtk_sheet_set_cell(sheet,7,0,GTK_JUSTIFY_LEFT,
+"color, border style, and many other attributes.");
+ gtk_sheet_set_cell(sheet, 8,0, GTK_JUSTIFY_LEFT,
+                    "You can drag & drop the selection");
+ gtk_sheet_set_cell(sheet, 9,0, GTK_JUSTIFY_LEFT,
+                    "and resize it clicking the right-bottom corner");
+ gtk_sheet_set_cell(sheet, 10,0, GTK_JUSTIFY_LEFT,
+                    "Store the selection on the clipboard pressing Ctrl-C");
+ gtk_sheet_set_cell(sheet, 11,0, GTK_JUSTIFY_LEFT,
+                    "(The selection handler has not been implemented yet)");
+
+
+
  gtk_signal_connect(GTK_OBJECT(sheet),
                     "key_press_event",
                     (GtkSignalFunc) clipboard_handler, 
@@ -531,21 +591,22 @@ activate_sheet_cell(GtkWidget *widget, gint row, gint column, gpointer data)
   gtk_entry_set_max_length(GTK_ENTRY(entry), 
 	GTK_SHENTRY(GTK_SHEET(widget)->sheet_entry)->text_max_length); 
 
- if((text=GTK_SHENTRY(GTK_SHEET(widget)->sheet_entry)->text))
+  if((text=GTK_SHENTRY(GTK_SHEET(widget)->sheet_entry)->text))
                           gtk_entry_set_text(GTK_ENTRY(entry), text);
- else
+  else
                           gtk_entry_set_text(GTK_ENTRY(entry), "");
 
- gtk_sheet_get_attributes(sheet,sheet->active_cell.row,
+  gtk_sheet_get_attributes(sheet,sheet->active_cell.row,
                                 sheet->active_cell.col, &attributes); 
 
- gtk_entry_set_editable(GTK_ENTRY(entry), attributes.is_editable);
+  gtk_entry_set_editable(GTK_ENTRY(entry), attributes.is_editable);
 
 }
 
 int main(int argc, char *argv[])
 {
   GtkWidget *label; 
+  GtkRequisition request;
   gint i;
 
   char *title[]= {"Example 1",
@@ -575,6 +636,8 @@ int main(int argc, char *argv[])
   gtk_widget_show(status_box);
 
   location=gtk_label_new("");
+  gtk_widget_size_request(location, &request);
+  gtk_widget_set_usize(location, 160, request.height);
   gtk_box_pack_start(GTK_BOX(status_box), location, FALSE, TRUE, 0);
   gtk_widget_show(location);
 
