@@ -283,12 +283,10 @@ struct _GtkSheet{
   /* Column Titles */
   GdkRectangle column_title_area;
   GdkWindow *column_title_window;
-  GtkWidget **column_button;
 
   /* Row Titles */
   GdkRectangle row_title_area;
   GdkWindow *row_title_window;
-  GtkWidget **row_button;
 
   /*scrollbars*/
   GtkWidget *vscrollbar;
@@ -640,11 +638,12 @@ gtk_sheet_range_set_border_color(GtkSheet *sheet, GtkSheetRange range, GdkColor
 /* set font for the given range */
 /* NOT IMPLEMENTED. I leave this for someone with experience on X fonts */
 void
-gtk_sheet_range_set_font(GtkSheet *sheet, ...);
+gtk_sheet_range_set_font(GtkSheet *sheet, GtkSheetRange range, GdkFont *font);
 
 
 /* get cell attributes of the given cell */
-void
+/* TRUE means that the cell is currently allocated */
+gint
 gtk_sheet_get_attributes(GtkSheet *sheet, gint row, gint col, GtkSheetCellAttr *attributes);
 
 
